==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/v5_1/res/template/DocTemplateDetailRes.java <==
package com.fasc.open.api.v5_1.res.template;

import com.fasc.open.api.bean.base.BaseBean;
import com.fasc.open.api.bean.common.TemplateField;

import java.util.List;

/**
 * @author Fadada
 * 2021/9/11 15:16:27
 */
public class DocTemplateDetailRes extends BaseBean {
    private String docTemplateId;
    private String docTemplateName;
    private String docTemplateStatus;
    private List<TemplateField> docFields;
    private String catalogName;
    private String createSerialNo;
    private String creatorMemberName ;
    private String storageType;

    public String getCreatorMemberName() {
        return creatorMemberName;
    }

    public void setCreatorMemberName(String creatorMemberName) {
        this.creatorMemberName = creatorMemberName;
    }

    public String getDocTemplateId() {
        return docTemplateId;
    }

    public void setDocTemplateId(String docTemplateId) {
        this.docTemplateId = docTemplateId;
    }

    public String getDocTemplateName() {
        return docTemplateName;
    }

    public void setDocTemplateName(String docTemplateName) {
        this.docTemplateName = docTemplateName;
    }

    public String getDocTemplateStatus() {
        return docTemplateStatus;
    }

    public void setDocTemplateStatus(String docTemplateStatus) {
        this.docTemplateStatus = docTemplateStatus;
    }

    public List<TemplateField> getDocFields() {
        return docFields;
    }

    public void setDocFields(List<TemplateField> docFields) {
        this.docFields = docFields;
    }

    public String getCatalogName() {
        return catalogName;
    }

    public void setCatalogName(String catalogName) {
        this.catalogName = catalogName;
    }

    public String getCreateSerialNo() {
        return createSerialNo;
    }

    public void setCreateSerialNo(String createSerialNo) {
        this.createSerialNo = createSerialNo;
    }

    public String getStorageType() {
        return storageType;
    }

    public void setStorageType(String storageType) {
        this.storageType = storageType;
    }
}

==> fasc-openapi-java-sdk-5.7.2.0815-sources.jar: com/fasc/open/api/v5_1/res/template/DocTemplateDetailRes.java <==
package com.fasc.open.api.v5_1.res.template;

import com.fasc.open.api.bean.base.BaseBean;
import com.fasc.open.api.bean.common.TemplateField;

import java.util.List;

/**
 * @author Fadada
 * 2021/9/11 15:16:27
 */
public class DocTemplateDetailRes extends BaseBean {
    private String docTemplateId;
    private String docTemplateName;
    private String docTemplateStatus;
    private List<TemplateField> docFields;
    private String catalogName;
    private String createSerialNo;
    private String creatorMemberName ;
    private String storageType;
    private String description;

    private Boolean useFda;

    public Boolean getUseFda() {
        return useFda;
    }

    public void setUseFda(Boolean useFda) {
        this.useFda = useFda;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getCreatorMemberName() {
        return creatorMemberName;
    }

    public void setCreatorMemberName(String creatorMemberName) {
        this.creatorMemberName = creatorMemberName;
    }

    public String getDocTemplateId() {
        return docTemplateId;
    }

    public void setDocTemplateId(String docTemplateId) {
        this.docTemplateId = docTemplateId;
    }

    public String getDocTemplateName() {
        return docTemplateName;
    }

    public void setDocTemplateName(String docTemplateName) {
        this.docTemplateName = docTemplateName;
    }

    public String getDocTemplateStatus() {
        return docTemplateStatus;
    }

    public void setDocTemplateStatus(String docTemplateStatus) {
        this.docTemplateStatus = docTemplateStatus;
    }

    public List<TemplateField> getDocFields() {
        return docFields;
    }

    public void setDocFields(List<TemplateField> docFields) {
        this.docFields = docFields;
    }

    public String getCatalogName() {
        return catalogName;
    }

    public void setCatalogName(String catalogName) {
        this.catalogName = catalogName;
    }

    public String getCreateSerialNo() {
        return createSerialNo;
    }

    public void setCreateSerialNo(String createSerialNo) {
        this.createSerialNo = createSerialNo;
    }

    public String getStorageType() {
        return storageType;
    }

    public void setStorageType(String storageType) {
        this.storageType = storageType;
    }
}
